@@ -34,7 +34,11 @@ class TypeHintChecker:
         # Request `lines` here and join to allow for correct handling of input from stdin
         self.lines = lines
         self.tree = self.get_typed_tree("".join(lines))  # flake8 doesn't strip newlines
-        self.suppress_none_returning: bool  # Set by flake8's config parser
+
+        # Set by flake8's config parser
+        self.suppress_none_returning: bool
+        self.suppress_dummy_args: bool
+        self.allow_untyped_defs: bool
 
     def run(self) -> Generator[FORMATTED_ERROR, None, None]:
         """
@@ -51,6 +55,10 @@ class TypeHintChecker:
         #
         # Flake8 handles all noqa and error code ignore configurations after the error is yielded
         for function in visitor.function_definitions:
+            # Skip yielding any errors from dynamically typed functions (function has no type hints)
+            if self.allow_untyped_defs and function.is_dynamically_typed():
+                continue
+
             # Create sentinels to check for mixed hint styles
             if function.has_type_comment:
                 has_type_comment = True
@@ -75,12 +83,17 @@ class TypeHintChecker:
 
             # Yield explicit errors for arguments that are missing annotations
             for arg in function.get_missed_annotations():
-                # Skip yielding return errors if the `--suppress-none-returning` flag is True and
+                # Skip yielding return errors if the `--suppress-none-returning` flag is `True` and
                 # the function has only `None` returns (which includes the case of no returns)
                 if arg.argname == "return" and self.suppress_none_returning:
                     if not arg.has_type_annotation and function.has_only_none_returns:
                         continue
 
+                # If the `--suppress-dummy-args` flag is `True`, skip yielding errors for any
+                # arguments named `_`
+                if arg.argname == "_" and self.suppress_dummy_args:
+                    continue
+
                 yield classify_error(function, arg).to_flake8()
 
     @classmethod
@@ -97,10 +110,30 @@ class TypeHintChecker:
             ),
         )
 
+        parser.add_option(
+            "--suppress-dummy-args",
+            default=False,
+            action="store_true",
+            parse_from_config=True,
+            help=(
+                "Suppress ANN000-level errors for dummy arguments, defined as '_'. (Default: False)"
+            ),
+        )
+
+        parser.add_option(
+            "--allow-untyped-defs",
+            default=False,
+            action="store_true",
+            parse_from_config=True,
+            help=("Suppress all errors for dynamically typed functions. (Default: False)"),
+        )
+
     @classmethod
     def parse_options(cls, options: Namespace) -> None:
         """Parse the custom configuration options given to flake8."""
         cls.suppress_none_returning = options.suppress_none_returning
+        cls.suppress_dummy_args = options.suppress_dummy_args
+        cls.allow_untyped_defs = options.allow_untyped_defs
 
     @staticmethod
     def get_typed_tree(src: str) -> ast.Module:
